from django.apps import AppConfig


class LogisticsConfig(AppConfig):
    name = "revpayment.logistics"
    label = "revpayment.logistics"
